@@ -1,8 +1,8 @@
 /* $Id$
  *
- * Internet Radio Locator for GTK+ 4.0
+ * Internet Radio Locator for GTK 4
  *
- * Copyright (C) 2014, 2015, 2016, 2017, 2018  Ole Aamot Software
+ * Copyright (C) 2014, 2015, 2016, 2017, 2018, 2022  Ole Aamot Software
  *
  * Author: Ole Aamot <ole@gnome.org>
  *
@@ -394,7 +394,7 @@ GtkWidget *create_gtk_internet_radio_locator_app(void)
 	
 	GTKInternetRadioLocatorData *gtk_internet_radio_locator_data = g_new0(GTKInternetRadioLocatorData, 1);
 	char *pmf;
-	gtk_window_set_title(GTK_WINDOW(gtk_internet_radio_locator_app), "Internet Radio Locator for GTK+ 4.0");
+	gtk_window_set_title(GTK_WINDOW(gtk_internet_radio_locator_app), "Internet Radio Locator for GTK 4");
 	gtk_internet_radio_locator = gtk_internet_radio_locator_data;
 	gtk_internet_radio_locator_data->settings = g_settings_new(GTK_INTERNET_RADIO_LOCATOR_UI);
 	selected_station_uri = g_variant_get_string(g_settings_get_value (gtk_internet_radio_locator_data->settings, "selected_station_uri"), &length);
