@@ -1,8 +1,8 @@
 /* $Id$
  *
- * GTK Internet Radio Locator for GTK+ 4.0
+ * GTK Internet Radio Locator for GTK 4
  *
- * Copyright (C) 2014, 2015, 2016, 2017, 2018  Ole Aamot Software
+ * Copyright (C) 2014, 2015, 2016, 2017, 2018, 2022  Aamot Software
  *
  * Author: Ole Aamot <ole@gnome.org>
  *
@@ -589,7 +589,7 @@ gtk_internet_radio_locator_window_cb (GtkApplication *app,
 	gtk_container_add (GTK_CONTAINER(window), GTK_WIDGET(grid));
 	g_signal_connect (window, "destroy", G_CALLBACK(gtk_main_quit), NULL);
 #endif
-	gtk_window_set_title (GTK_WINDOW(window), _("Internet Radio Locator for GTK+ 4.0"));
+	gtk_window_set_title (GTK_WINDOW(window), _("Internet Radio Locator for GTK 4"));
 	gtk_window_set_default_size (GTK_WINDOW(window), 1440, 720);
 
 	gtk_internet_radio_locator_app = create_gtk_internet_radio_locator_app();
@@ -759,7 +759,7 @@ main (int argc,
 	/* give the window a 10px wide border */
 	gtk_container_set_border_width (GTK_CONTAINER (window), 10);
 	/* give it the title */
-	gtk_window_set_title (GTK_WINDOW (window), _("Internet Radio Locator for GTK+ 4.0"));
+	gtk_window_set_title (GTK_WINDOW (window), _("Internet Radio Locator for GTK 4"));
 	/* Connect the destroy event of the window with our on_destroy function
 	 * When the window is about to be destroyed we get a notificaiton and
 	 * stop the main GTK loop
